import { jsx } from '@emotion/core';
import React, { Fragment } from 'react';
import _pt from 'prop-types';
import { Link } from 'gatsby';
import { sizeStyles } from '../Text/Text.helpers.esm.js';

function Breadcrumb({
  children,
  separator = `arrow`,
  size = `L`,
  ...rest
}) {
  return jsx("nav", {
    "aria-label": "breadcrumb",
    ...rest
  }, jsx("ol", {
    css: {
      listStyle: `none`,
      margin: 0,
      padding: 0,
      display: `flex`,
      flexWrap: `wrap`
    }
  }, React.Children.map(children, child => {
    if ( /*#__PURE__*/React.isValidElement(child)) {
      return /*#__PURE__*/React.cloneElement(child, {
        separator,
        size
      });
    }

    return child;
  })));
}
Breadcrumb.propTypes = {
  separator: _pt.oneOf([`arrow`, `slash`]),
  size: _pt.oneOf(["L", "M", "S"])
};
Breadcrumb.Item = BreadcrumbItem;

const breadcrumbItemCss = theme => ({
  display: `flex`,
  alignItems: `center`,
  color: theme.colors.purple[50],
  fontFamily: theme.fonts.heading
});

function BreadcrumbItem({
  to,
  active,
  separator,
  size = `L`,
  onClick,
  children,
  ...rest
}) {
  return jsx("li", {
    css: theme => [breadcrumbItemCss(theme), sizeStyles[size](theme), active && {
      color: theme.colors.grey[60]
    }],
    ...rest
  }, to ? jsx(Fragment, null, jsx(Link, {
    to: to,
    onClick: onClick,
    css: {
      textDecoration: `none`,
      color: `inherit`
    }
  }, children), jsx(BreadcrumbSeparator, {
    separator: separator
  })) : children);
}

BreadcrumbItem.propTypes = {
  separator: _pt.oneOf([`arrow`, `slash`]),
  size: _pt.oneOf(["L", "M", "S"]),
  to: _pt.string,
  active: _pt.bool,
  onClick: _pt.func
};
BreadcrumbItem.displayName = `Breadcrumb.Item`;

const baseSeparatorCss = theme => ({
  color: theme.colors.grey[60],
  marginRight: theme.space[4],
  marginLeft: theme.space[4],
  verticalAlign: `middle`
});

const breadcrumbSlashCss = theme => [baseSeparatorCss(theme), {
  color: theme.colors.grey[30]
}];

const breadcrumbArrowCss = theme => [baseSeparatorCss(theme), {
  color: theme.colors.grey[60]
}];

function BreadcrumbSeparator({
  separator,
  ...rest
}) {
  return separator === `arrow` ? jsx("svg", {
    width: "6",
    height: "9",
    viewBox: "0 0 6 9",
    fill: "currentColor",
    css: breadcrumbArrowCss,
    ...rest
  }, jsx("path", {
    d: "M6 4.5L1.5 8.39711L1.5 0.602886L6 4.5Z"
  })) : jsx("span", {
    css: breadcrumbSlashCss
  }, "/");
}

BreadcrumbSeparator.propTypes = {
  separator: _pt.oneOf([`arrow`, `slash`]),
  size: _pt.oneOf(["L", "M", "S"])
};

export { Breadcrumb };
//# sourceMappingURL=Breadcrumb.esm.js.map
