const dropdownCss = theme => ({
  background: theme.colors.primaryBackground,
  border: `0.5px solid ${theme.colors.blackFade[10]}`,
  borderRadius: theme.radii[2],
  outline: "none",
  boxShadow: theme.shadows.floating,
  transformOrigin: "50% top",
  overflow: "auto",
  maxHeight: "20rem",
  // @TODO port to `Combobox` — providing this bit of vertical padding
  // aligns the first and last action items' visual size with the rest of the
  // dropdown items
  paddingTop: theme.space[2],
  paddingBottom: theme.space[2],
  "[data-selected]": {
    background: theme.colors.grey[10],
    color: theme.colors.grey[90]
  }
});
const dropdownSizeCss = {
  AUTO: _theme => ({}),
  MAX_CONTENT: _theme => ({
    width: `max-content`
  }),
  LEGACY: theme => ({
    width: `max-content`,
    [theme.mediaQueries.phablet]: {
      width: "80vw",
      maxWidth: "20rem"
    }
  })
};
const menuItemCss = theme => ({
  cursor: `pointer`,
  color: theme.colors.grey[90],
  fontSize: theme.fontSizes[1],
  // @TODO consider bumping horizontal, decrease vertical padding for `Combobox` analog to this
  padding: `${theme.space[3]} ${theme.space[5]}`,
  lineHeight: theme.lineHeights.default,
  overflow: "hidden",
  wordWrap: `break-word`,
  overflowWrap: `break-word`,
  hyphens: `auto`,
  display: `block`,
  textDecoration: `none`
});
const menuItemToneCss = {
  DEFAULT: theme => ({
    color: theme.colors.grey[90],
    "[data-selected] > &": {
      color: theme.colors.grey[90]
    }
  }),
  CRITICAL: theme => ({
    color: theme.colors.red[90],
    "[data-selected] &": {
      color: theme.colors.red[90]
    }
  })
};
const menuItemIconCss = theme => ({
  // Based on suggestion from https://blog.prototypr.io/align-svg-icons-to-text-and-say-goodbye-to-font-icons-d44b3d7b26b4
  top: `.125rem`,
  position: `relative`,
  marginRight: theme.space[3],
  width: theme.fontSizes[2],
  height: theme.fontSizes[2],
  transition: `0.5s`
});
const menuItemIconToneCss = {
  DEFAULT: theme => ({
    color: theme.colors.grey[50],
    "[data-selected] &": {
      color: theme.colors.grey[50]
    }
  }),
  CRITICAL: theme => ({
    color: theme.colors.red[50],
    "[data-selected] &": {
      color: theme.colors.red[90]
    }
  })
};
const dropdownButtonCss = theme => ({
  cursor: "pointer",
  display: "flex",
  alignItems: "center",
  border: `1px solid ${theme.colors.grey[30]}`,
  borderRadius: theme.radii[2],
  color: theme.colors.grey[90],
  fontSize: theme.fontSizes[2],
  padding: `${theme.space[2]} ${theme.space[4]}`,
  width: "100%",
  "&:focus": {
    borderColor: theme.colors.purple[40],
    boxShadow: `0 0 0 3px ${theme.colors.purple[20]}`,
    outline: 0,
    transition: `box-shadow 0.15s ease-in-out`
  }
});
const dropdownButtonIconCss = _theme => ({
  marginInlineStart: `auto`,
  transition: "transform .3s",
  "[aria-expanded] > &": {
    transform: "rotate(180deg)"
  }
});
const dropdownDividerCss = theme => ({
  // we're applying this to `hr`
  border: 0,
  borderTop: `1px solid ${theme.colors.grey[20]}`,
  marginBottom: theme.space[2],
  marginTop: theme.space[2]
});
const dropdownHeaderCss = theme => ({
  color: theme.colors.grey[50],
  fontFamily: theme.fonts.sans,
  fontSize: theme.fontSizes[0],
  fontWeight: theme.fontWeights.body,
  margin: 0,
  padding: `${theme.space[3]} ${theme.space[5]}`
});

export { dropdownButtonCss, dropdownButtonIconCss, dropdownCss, dropdownDividerCss, dropdownHeaderCss, dropdownSizeCss, menuItemCss, menuItemIconCss, menuItemIconToneCss, menuItemToneCss };
//# sourceMappingURL=DropdownMenu.styles.esm.js.map
