import { jsx } from '@emotion/core';
import { BaseHeading } from '../BaseHeading/BaseHeading.esm.js';
import { showCustomCssDeprecationMessage } from '../../utils/maintenance/deprecationMessages.esm.js';

/** @jsx jsx */

const baseCss = theme => ({
  margin: 0,
  lineHeight: theme.lineHeights.heading
});

const fontVariantCss = {
  DISPLAY: theme => ({
    fontFamily: theme.fonts.heading
  }),
  UI: theme => ({
    fontFamily: theme.fonts.heading
  })
};

const modifiedCss = (variant, tone) => theme => [{
  color: theme.tones[tone].text
}, variant === `PRIMARY` && {
  fontWeight: theme.fontWeights.bold
}, variant === `EMPHASIZED` && {
  fontWeight: theme.fontWeights.extraBold
}, variant === `LIGHT` && {
  fontWeight: theme.fontWeights.body,
  textTransform: `uppercase`
}];

function Heading({
  tone = `NEUTRAL`,
  variant = `PRIMARY`,
  fontVariant = `DISPLAY`,
  as = `h2`,
  customCss,
  ...rest
}) {
  showCustomCssDeprecationMessage(customCss);
  return jsx(BaseHeading, {
    as: as,
    css: theme => [baseCss(theme), modifiedCss(variant, tone)(theme), fontVariantCss[fontVariant](theme), customCss],
    ...rest
  });
}

export { Heading };
//# sourceMappingURL=Heading.esm.js.map
