import { jsx } from '@emotion/core';
import { useContext, createContext } from 'react';
import _pt from 'prop-types';
import { MdClose } from '../../node_modules/react-icons/md/index.esm.esm.js';
import { Heading } from '../Heading/Heading.esm.js';
import { headerCss, titleCss, closeButtonCss, closeIconCss, bodyCss, bodyVariantCss, actionsCss } from './StyledModal.styles.esm.js';

const StyledModalContext = /*#__PURE__*/createContext({
  variant: `DEFAULT`
});
function useStyledModalContext() {
  return useContext(StyledModalContext);
}
function StyledModal({
  children,
  variant = `DEFAULT`
}) {
  return jsx(StyledModalContext.Provider, {
    value: {
      variant
    }
  }, children);
}
StyledModal.propTypes = {
  children: _pt.node.isRequired,
  variant: _pt.oneOf([`DEFAULT`, `SUCCESS`, `WARNING`, `ERROR`, `ACTION`, `RETAKE`])
};
function StyledModalHeader({
  children,
  onCloseButtonClick,
  closeButtonLabel = `Close modal`
}) {
  return jsx("div", {
    css: headerCss
  }, jsx(Heading, {
    css: titleCss,
    fontVariant: "UI"
  }, children), jsx(StyledModalCloseButton, {
    onClick: onCloseButtonClick,
    "aria-label": closeButtonLabel
  }));
}
StyledModalHeader.propTypes = {
  children: _pt.node.isRequired,
  onCloseButtonClick: _pt.func,
  closeButtonLabel: _pt.string
};
function StyledModalCloseButton(props) {
  return jsx("button", {
    css: closeButtonCss,
    ...props
  }, jsx(MdClose, {
    css: closeIconCss
  }));
}
function StyledModalBody({
  children
}) {
  const {
    variant
  } = useStyledModalContext();
  return jsx("div", {
    css: theme => [bodyCss(theme), bodyVariantCss[variant](theme)]
  }, children);
}
StyledModalBody.propTypes = {
  children: _pt.node.isRequired
};
function StyledModalActions({
  children
}) {
  return jsx("div", {
    css: actionsCss
  }, children);
}
StyledModalActions.propTypes = {
  children: _pt.node.isRequired
};

export { StyledModal, StyledModalActions, StyledModalBody, StyledModalCloseButton, StyledModalHeader, useStyledModalContext };
//# sourceMappingURL=StyledModal.esm.js.map
