import { jsx } from '@emotion/core';
import { forwardRef, Fragment } from 'react';
import 'prop-types';
import { visuallyHiddenCss } from '../../stylesheets/a11y.esm.js';
import ToggleGutter, { ToggleGutterTagName, toggleGutterDisabledCss, toggleGutterCheckedCss, toggleGutterFocusCss } from './ToggleGutter.esm.js';
import { toggleWrapperCss, toggleLabelCss, toggleLabelContentCss, toggleHintCss } from './Toggle.styles.esm.js';

const BaseToggle = /*#__PURE__*/forwardRef(function BaseToggle({
  tone = `SUCCESS`,
  className,
  style,
  ...rest
}, ref) {
  return jsx(Fragment, null, jsx("input", {
    ref: ref,
    type: "checkbox",
    value: "true",
    css: theme => [visuallyHiddenCss, {
      [`&:disabled + ${ToggleGutterTagName}`]: toggleGutterDisabledCss(theme),
      [`&:checked + ${ToggleGutterTagName}`]: toggleGutterCheckedCss(tone, rest.disabled)(theme),
      [`&:focus + ${ToggleGutterTagName}`]: toggleGutterFocusCss(theme)
    }],
    ...rest
  }), jsx(ToggleGutter, {
    className: className,
    style: style
  }));
});
var ToggleCheckbox = /*#__PURE__*/forwardRef(function ToggleCheckbox({
  id,
  label,
  hint,
  labelPosition = "end",
  className,
  style,
  disabled,
  ...rest
}, ref) {
  return jsx("div", {
    css: toggleWrapperCss,
    className: className,
    style: style
  }, jsx("label", {
    htmlFor: id,
    css: theme => [toggleLabelCss(), disabled && {
      color: theme.colors.grey[50],
      cursor: `not-allowed`
    }]
  }, jsx(BaseToggle, {
    ref: ref,
    id: id,
    disabled: disabled,
    ...rest,
    css: theme => [labelPosition === `end` ? {
      marginRight: theme.space[4]
    } : {
      marginLeft: theme.space[4],
      order: 1
    }],
    "aria-describedby": !!hint ? `${id}__hint` : ``
  }), jsx("div", {
    css: toggleLabelContentCss
  }, label)), hint && jsx("small", {
    id: `${id}__hint`,
    css: theme => [toggleHintCss(theme), disabled && {
      color: theme.colors.grey[50]
    }]
  }, hint));
});

export default ToggleCheckbox;
//# sourceMappingURL=ToggleCheckbox.esm.js.map
