import { jsx } from '@emotion/core';
import { useRef } from 'react';
import _pt from 'prop-types';
import { visuallyHiddenCss } from '../../stylesheets/a11y.esm.js';
import ToggleGutter, { ToggleGutterTagName, toggleGutterFocusCss, toggleGutterCheckedCss } from './ToggleGutter.esm.js';
import { toggleLabelCss } from './Toggle.styles.esm.js';

function ToggleSwitch({
  id,
  valueOn,
  valueOff,
  labelOn,
  labelOff,
  value = valueOff,
  tone,
  className,
  style,
  ...rest
}) {
  const inputOnRef = useRef(null);
  const inputOffRef = useRef(null);
  const optionOnId = `${id}__on`;
  const optionOffId = `${id}__off`;
  const isOn = value === valueOn;

  const toggle = () => {
    const inputOn = inputOnRef.current;
    const inputOff = inputOffRef.current;

    if (!inputOn || !inputOff) {
      return;
    }

    if (isOn) {
      inputOff.focus();
      inputOff.click();
    } else {
      inputOn.focus();
      inputOn.click();
    }
  };

  return jsx("div", {
    id: id,
    className: className,
    style: style,
    css: theme => [{
      display: `flex`,
      alignItems: `center`,
      // We can rely on "> ToggleGutterTagName" here since we have full control over direct children
      [`&:focus-within > ${ToggleGutterTagName}`]: toggleGutterFocusCss(theme)
    }, toggleLabelCss()],
    onClick: e => {
      if (!inputOnRef.current || !inputOffRef.current) {
        return;
      }

      const target = e.target;

      if (target.tagName === `LABEL`) {
        const inputOn = inputOnRef.current;
        const inputOff = inputOffRef.current;
        const labelFor = target.htmlFor;

        if (labelFor === optionOnId && isOn) {
          e.preventDefault();
          inputOff.focus();
          inputOff.click();
        }

        if (labelFor === optionOffId && !isOn) {
          e.preventDefault();
          inputOn.focus();
          inputOn.click();
        }
      } else if (target.tagName === ToggleGutterTagName.toUpperCase()) {
        toggle();
      }
    },
    onKeyPress: e => {
      if (e.key !== " ") {
        return;
      }

      toggle();
    }
  }, jsx("input", {
    type: "radio",
    id: optionOffId,
    name: id,
    value: valueOff,
    checked: !isOn,
    css: visuallyHiddenCss,
    ref: inputOffRef,
    ...rest
  }), jsx("label", {
    htmlFor: optionOffId
  }, labelOff), jsx(ToggleGutter, {
    css: theme => [{
      marginLeft: theme.space[3],
      marginRight: theme.space[3]
    }, isOn && toggleGutterCheckedCss(tone)(theme)]
  }), jsx("input", {
    type: "radio",
    id: optionOnId,
    name: id,
    value: valueOn,
    checked: isOn,
    css: visuallyHiddenCss,
    ref: inputOnRef,
    ...rest
  }), jsx("label", {
    htmlFor: optionOnId
  }, labelOn));
}
ToggleSwitch.propTypes = {
  id: _pt.string.isRequired,
  value: _pt.string.isRequired,
  valueOn: _pt.string.isRequired,
  valueOff: _pt.string.isRequired,
  labelOn: _pt.node.isRequired,
  labelOff: _pt.node.isRequired,
  className: _pt.string
};

export default ToggleSwitch;
//# sourceMappingURL=ToggleSwitch.esm.js.map
