/**
 * Base styles
 */
const disabledStyles = theme => ({
  background: theme.colors.grey[10],
  cursor: `not-allowed`
});

const placeholderStyles = theme => ({
  color: theme.colors.grey[50]
});

const disabledPlaceholderStyles = theme => ({
  color: theme.colors.grey[40]
});

const focusedStyles = theme => ({
  outline: `0`,
  transition: `box-shadow 0.15s ease-in-out`,
  boxShadow: `0 0 0 3px ${theme.colors.purple[20]}`,
  borderColor: theme.colors.purple[60]
});

const focusedErrorStyles = theme => ({
  outline: `0`,
  transition: `box-shadow 0.15s ease-in-out`,
  boxShadow: `0 0 0 3px ${theme.colors.red[10]}`,
  borderColor: theme.colors.red[30]
});

const errorStyles = theme => ({
  borderColor: theme.colors.red[60]
});

const baseFormControlStyles = {
  disabledStyles,
  disabledPlaceholderStyles,
  focusedStyles,
  focusedErrorStyles,
  errorStyles,
  placeholderStyles
};
const baseInputCss = theme => [{
  borderWidth: 1,
  borderStyle: `solid`,
  borderColor: theme.colors.grey[30],
  borderRadius: `6px`,
  background: theme.colors.white,
  color: theme.colors.grey[90],
  fontFamily: theme.fonts.system,
  fontSize: theme.fontSizes[2],
  height: `2.25rem`,
  padding: `0 ${theme.space[3]}`,
  position: `relative`,
  width: `100%`,
  zIndex: 1,
  WebkitAppearance: `none`,
  ":focus": baseFormControlStyles.focusedStyles(theme),
  ":disabled": baseFormControlStyles.disabledStyles(theme),
  "&:disabled::placeholder": baseFormControlStyles.disabledPlaceholderStyles(theme),
  "&::placeholder": baseFormControlStyles.placeholderStyles(theme),
  "&[aria-invalid='true']": baseFormControlStyles.errorStyles(theme),
  "&[aria-invalid='true']:focus": baseFormControlStyles.focusedErrorStyles(theme)
}];
function getOptionLabelCss(optionControlSize = "0px", optionsDirection = `column`) {
  return theme => ({
    color: theme.colors.grey[90],
    cursor: `pointer`,
    lineHeight: theme.lineHeights.dense,
    fontSize: theme.fontSizes[2],
    paddingLeft: `calc(${optionControlSize} + ${optionsDirection === `row` ? theme.space[2] : theme.space[4]})`
  });
}
function getOptionLabelOffsetStyles(optionsDirection = `column`) {
  return theme => ({
    paddingLeft: optionsDirection === `row` ? theme.space[2] : theme.space[4]
  });
}
function getFieldLayoutStyles(layout = `vertical`, isGroupField = false) {
  const isHorizontal = layout === `horizontal`;

  const labelCss = theme => [isHorizontal && {
    [theme.mediaQueries.desktop]: [{
      display: `table-cell`,
      minWidth: `20ch`,
      maxWidth: `20ch`,
      // Use box-sizing in combination with width and padding-right
      // to ensure that the label text itself takes no more than 20 chars in width
      boxSizing: `content-box`,
      width: `20ch`,
      paddingRight: theme.space[7],
      paddingTop: theme.space[3],
      verticalAlign: `top`
    }, isGroupField && {
      // Unfortunately, setting "display" to <legend> does not seem to work in Chrome,
      // So instead we are going to rely on "float" for group form fields
      float: `left`
    }]
  }];

  const fieldBodyCss = theme => [isHorizontal && {
    [theme.mediaQueries.desktop]: {
      display: `table-cell`,
      width: `100%`,
      verticalAlign: `top`
    }
  }];

  return {
    labelCss: labelCss,
    fieldBodyCss: fieldBodyCss
  };
}

export { baseFormControlStyles, baseInputCss, getFieldLayoutStyles, getOptionLabelCss, getOptionLabelOffsetStyles };
//# sourceMappingURL=index.esm.js.map
